# Description
This repository contains an integration between hxai and the Nuxeo Platform

# How to build
```
git clone https://github.com/nuxeo-sandbox/nuxeo-hxai-connector
cd nuxeo-hxai-connector
mvn clean install
```

# Features
## An API Client
The API client is auto-generated from an openapi definition [file](https://github.com/nuxeo-sandbox/nuxeo-hxai-connector/blob/master/nuxeo-hxai-connector-client/src/main/resources/hxai-1.0.json)

## A Nuxeo Service
Basic ingest operations like uploading files and sending events are implemented in the HxAi [service](https://github.com/nuxeo-sandbox/nuxeo-hxai-connector/blob/master/nuxeo-hxai-connector-core/src/main/java/org/nuxeo/hxai/service/HxAi.java)

## Converters
HxAi only accepts a limited set of file formats which requires to run conversions before sending the files.
The xml contributions can be found [here](https://github.com/nuxeo-sandbox/nuxeo-hxai-connector/blob/master/nuxeo-hxai-connector-core/src/main/resources/OSGI-INF/converter-contrib.xml)

## A Stream processor
This plugin reuses the pipes framework from the nuxeo-ai plugin and implements a [stream processor](https://github.com/nuxeo-sandbox/nuxeo-hxai-connector/blob/master/nuxeo-hxai-connector-core/src/main/java/org/nuxeo/hxai/processor/HxAiIngestProcessor.java) which can be configured in multiple pipes.
Please refer to the nuxeo-ai [documentation](https://github.com/nuxeo/nuxeo-ai?tab=readme-ov-file#nuxeo-pipes) to understand how pipes are configured

The stream processor specific options are:

| Option name  | description                                                |
|--------------|------------------------------------------------------------|
| ingestAction | The ingest API action to perform: create, update or delete |

## Sample ingest pipeline
The marketplace package contains a [sample ingest pipeline](https://github.com/nuxeo-sandbox/nuxeo-hxai-connector/tree/master/nuxeo-hxai-connector-package/src/main/resources/install/templates/nuxeo-hxai) which is deployed with the `nuxeo-hxai` configuration template.

**The sample configuration only handles File documents and the documentCreated event **

# How to run
## Configuration
The following nuxeo.conf properties are available to configure the plugin

| Property name             | description                                                                        |
|---------------------------|------------------------------------------------------------------------------------|
| nuxeo.hxai.ingest.enabled | Enable or disable the default Hxai ingestion pipeline                              |
| hxai.api.client.id        | The Hxai client ID                                                                 |
| hxai.api.client.secret    | The Hxai client secret                                                             |
| hxai.api.auth.baseurl     | The IDP base url (ex: https://auth.iam.dev.experience.hyland.com)                  |
| hxai.api.ingest.baseurl   | The Hxai ingest base url (ex: https://ingestion-api.insight.dev.ncp.hyland.com/v1) |
| hxai.api.ingest.env.key   | The ingest environment key                                                         |

## Sample docker compose
This plugin includes an image builder and a sample docker compose file. Assuming the docker image was built with maven:

```bash
cat << EOF >> .env
NUXEO_CLID=
EOF

cat << EOF >> conf.d/hxai.conf
hxai.api.client.id=
hxai.api.client.secret=
hxai.api.auth.baseurl=
hxai.api.ingest.baseurl=
hxai.api.ingest.env.key=
EOF

docker compose up -d
```

# Known limitations
This plugin is a work in progress.

# Support

**These features are not part of the Nuxeo Production platform.**

These solutions are provided for inspiration and we encourage customers to use them as code samples and learning resources.

This is a moving project (no API maintenance, no deprecation process, etc.) If any of these solutions are found to be useful for the Nuxeo Platform in general, they will be integrated directly into platform, not maintained here.

# License

[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0.html)

# About Nuxeo

Nuxeo Platform is an open source Content Services platform, written in Java. Data can be stored in both SQL & NoSQL databases.

The development of the Nuxeo Platform is mostly done by Nuxeo employees with an open development model.

The source code, documentation, roadmap, issue tracker, testing, benchmarks are all public.

Typically, Nuxeo users build different types of information management solutions for [document management](https://www.nuxeo.com/solutions/document-management/), [case management](https://www.nuxeo.com/solutions/case-management/), and [digital asset management](https://www.nuxeo.com/solutions/dam-digital-asset-management/), use cases. It uses schema-flexible metadata & content models that allows content to be repurposed to fulfill future use cases.

More information is available at [www.nuxeo.com](https://www.nuxeo.com)
